#ifndef ALFI_H
#define ALFI_H

#include <pc.h>

#define ALFI_ENGINE_LINE	0x378
#define ALFI_PEN_LINE           0x37A
#define ALFI_PEN_BIT 		0x02	/* auto line-feed bit */
#define ALFI_TIMEOUT		15
#define ALFI_PEN_TIMEOUT	50
#define ALFI_PEN_DOWN		0x02
#define ALFI_PEN_UP		0x00
#define ALFI_SHUT_MOTORS	0x00

#ifndef TRUE
#define TRUE                    0x01
#endif

#ifndef FALSE
#define FALSE                   0x00
#endif

#define ALFI_RIGHT              1
#define ALFI_LEFT               (-1)
#define ALFI_UP                 1
#define ALFI_DOWN               (-1)

#define alfi_speed_send(byte)           outportb(ALFI_ENGINE_LINE, (byte))
#define alfi_speed_pen_send(byte)       outportb(ALFI_PEN_LINE, (byte))

#define alfi_send(byte)		alfi_speed_send((byte)); \
delay (ALFI_TIMEOUT)

#define alfi_pen_send(byte)     alfi_speed_pen_send((byte)); \
delay (ALFI_PEN_TIMEOUT)

#define alfi_shut_motors()      alfi_speed_send(ALFI_SHUT_MOTORS)
#define alfi_force_pen_up()     alfi_speed_pen_send(ALFI_PEN_UP)

#define alfi_locate(x, y)       alfi_move((x)-alfi_x, (y)-alfi_y)

struct alfi_engine_st
  {
    char *control;		/* current driving method */
    int ticks;			/* size of control */
    int index;			/* index of control */
  };

extern struct alfi_engine_st alfi_h_engine;
extern struct alfi_engine_st alfi_v_engine;
extern int alfi_x;
extern int alfi_y;
extern int alfi_pen_status;

extern void alfi_reset ();
extern void alfi_pen (int);
extern void alfi_line (int x, int y);
extern void alfi_move (int, int);
extern void alfi_horizontal (int);
extern void alfi_vertical (int);

#endif
